import { AccelbyteSDK, ApiArgs, IResponse } from '@accelbyte/sdk';
import { z } from 'zod';
import { AxiosInstance } from 'axios';

declare const NamespaceContext: z.ZodObject<{
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    publisherNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    studioNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    type: z.ZodNullable<z.ZodOptional<z.ZodEnum<["Game", "Publisher", "Studio"]>>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    publisherNamespace?: string | null | undefined;
    studioNamespace?: string | null | undefined;
    type?: "Game" | "Publisher" | "Studio" | null | undefined;
}, {
    namespace?: string | null | undefined;
    publisherNamespace?: string | null | undefined;
    studioNamespace?: string | null | undefined;
    type?: "Game" | "Publisher" | "Studio" | null | undefined;
}>;
interface NamespaceContext extends z.TypeOf<typeof NamespaceContext> {
}

declare const NamespaceCreate: z.ZodObject<{
    displayName: z.ZodString;
    namespace: z.ZodString;
}, "strip", z.ZodTypeAny, {
    namespace: string;
    displayName: string;
}, {
    namespace: string;
    displayName: string;
}>;
interface NamespaceCreate extends z.TypeOf<typeof NamespaceCreate> {
}

declare const NamespaceInfo: z.ZodObject<{
    clientId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    createdAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    displayName: z.ZodString;
    namespace: z.ZodString;
    parentNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "DELETED", "INACTIVE"]>>>;
    updatedAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}>;
interface NamespaceInfo extends z.TypeOf<typeof NamespaceInfo> {
}

declare const NamespaceInfoArray: z.ZodArray<z.ZodObject<{
    clientId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    createdAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    displayName: z.ZodString;
    namespace: z.ZodString;
    parentNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "DELETED", "INACTIVE"]>>>;
    updatedAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}>, "many">;
interface NamespaceInfoArray extends z.TypeOf<typeof NamespaceInfoArray> {
}

declare const NamespacePublisherInfo: z.ZodObject<{
    publisher: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    publisherNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    publisherNamespace?: string | null | undefined;
    publisher?: boolean | null | undefined;
}, {
    publisherNamespace?: string | null | undefined;
    publisher?: boolean | null | undefined;
}>;
interface NamespacePublisherInfo extends z.TypeOf<typeof NamespacePublisherInfo> {
}

declare const NamespaceStatusUpdate: z.ZodObject<{
    status: z.ZodEnum<["ACTIVE", "INACTIVE"]>;
}, "strip", z.ZodTypeAny, {
    status: "ACTIVE" | "INACTIVE";
}, {
    status: "ACTIVE" | "INACTIVE";
}>;
interface NamespaceStatusUpdate extends z.TypeOf<typeof NamespaceStatusUpdate> {
}

declare const NamespaceUpdate: z.ZodObject<{
    displayName: z.ZodString;
}, "strip", z.ZodTypeAny, {
    displayName: string;
}, {
    displayName: string;
}>;
interface NamespaceUpdate extends z.TypeOf<typeof NamespaceUpdate> {
}

/**
 * AUTO GENERATED
 */

declare function NamespaceAdminApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getNamespaces: (queryParams?: {
        activeOnly?: boolean | null | undefined;
    } | undefined) => Promise<NamespaceInfoArray>;
    createNamespace: (data: NamespaceCreate) => Promise<NamespaceInfo>;
    deleteNamespace_ByNamespace: () => Promise<NamespaceInfo>;
    getNamespace_ByNamespace: (queryParams?: {
        activeOnly?: boolean | null | undefined;
    } | undefined) => Promise<NamespaceInfo>;
    getGame: (queryParams?: {
        activeOnly?: boolean | null | undefined;
    } | undefined) => Promise<NamespaceInfoArray>;
    patchBasic: (data: NamespaceUpdate) => Promise<NamespaceInfo>;
    getChild: (queryParams?: {
        activeOnly?: boolean | null | undefined;
    } | undefined) => Promise<NamespaceInfoArray>;
    patchStatus: (data: NamespaceStatusUpdate) => Promise<NamespaceInfo>;
    getContext: () => Promise<NamespaceContext>;
    getPublisher: () => Promise<NamespacePublisherInfo>;
};

declare const ConfigCreate: z.ZodObject<{
    key: z.ZodString;
    value: z.ZodString;
}, "strip", z.ZodTypeAny, {
    value: string;
    key: string;
}, {
    value: string;
    key: string;
}>;
interface ConfigCreate extends z.TypeOf<typeof ConfigCreate> {
}

declare const ConfigInfo: z.ZodObject<{
    createdAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    key: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    updatedAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    value: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    value?: string | null | undefined;
    createdAt?: string | null | undefined;
    updatedAt?: string | null | undefined;
    key?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    value?: string | null | undefined;
    createdAt?: string | null | undefined;
    updatedAt?: string | null | undefined;
    key?: string | null | undefined;
}>;
interface ConfigInfo extends z.TypeOf<typeof ConfigInfo> {
}

declare const ConfigUpdate: z.ZodObject<{
    value: z.ZodString;
}, "strip", z.ZodTypeAny, {
    value: string;
}, {
    value: string;
}>;
interface ConfigUpdate extends z.TypeOf<typeof ConfigUpdate> {
}

/**
 * AUTO GENERATED
 */

declare function ConfigAdminApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    createConfig: (data: ConfigCreate) => Promise<ConfigInfo>;
    deleteConfig_ByConfigKey: (configKey: string) => Promise<unknown>;
    getConfig_ByConfigKey: (configKey: string) => Promise<ConfigInfo>;
    patchConfig_ByConfigKey: (configKey: string, data: ConfigUpdate) => Promise<ConfigInfo>;
    getPublisherConfig_ByConfigKey: (configKey: string) => Promise<ConfigInfo>;
};

declare const AddCountryGroupRequest: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface AddCountryGroupRequest extends z.TypeOf<typeof AddCountryGroupRequest> {
}

declare const AddCountryGroupResponse: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface AddCountryGroupResponse extends z.TypeOf<typeof AddCountryGroupResponse> {
}

declare const CountryGroupObject: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface CountryGroupObject extends z.TypeOf<typeof CountryGroupObject> {
}

declare const CountryObjectArray: z.ZodArray<z.ZodObject<{
    code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    code?: string | null | undefined;
    name?: string | null | undefined;
}, {
    code?: string | null | undefined;
    name?: string | null | undefined;
}>, "many">;
interface CountryObjectArray extends z.TypeOf<typeof CountryObjectArray> {
}

declare const RetrieveCountryGroupResponseArray: z.ZodArray<z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>, "many">;
interface RetrieveCountryGroupResponseArray extends z.TypeOf<typeof RetrieveCountryGroupResponseArray> {
}

declare const UpdateCountryGroupRequest: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface UpdateCountryGroupRequest extends z.TypeOf<typeof UpdateCountryGroupRequest> {
}

/**
 * AUTO GENERATED
 */

declare function MiscAdminApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getMiscCountries_DEPRECATED: (queryParams?: {
        lang?: string | null | undefined;
    } | undefined) => Promise<CountryObjectArray>;
    getMiscLanguages: () => Promise<unknown>;
    getMiscTimezones: () => Promise<unknown>;
    getMiscCountrygroups: (queryParams?: {
        groupCode?: string | null | undefined;
    } | undefined) => Promise<RetrieveCountryGroupResponseArray>;
    createMiscCountrygroup: (data: AddCountryGroupRequest) => Promise<AddCountryGroupResponse>;
    deleteMiscCountrygroup_ByCountryGroupCode: (countryGroupCode: string) => Promise<unknown>;
    updateMiscCountrygroup_ByCountryGroupCode: (countryGroupCode: string, data: UpdateCountryGroupRequest) => Promise<CountryGroupObject>;
};

declare const UserProfileAdmin: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "INACTIVE"]>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
}, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
}>;
interface UserProfileAdmin extends z.TypeOf<typeof UserProfileAdmin> {
}

declare const UserProfileBulkRequest: z.ZodObject<{
    userIds: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
}, "strip", z.ZodTypeAny, {
    userIds?: string[] | null | undefined;
}, {
    userIds?: string[] | null | undefined;
}>;
interface UserProfileBulkRequest extends z.TypeOf<typeof UserProfileBulkRequest> {
}

declare const UserProfileInfo: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "INACTIVE"]>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}>;
interface UserProfileInfo extends z.TypeOf<typeof UserProfileInfo> {
}

declare const UserProfilePrivateInfo: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "INACTIVE"]>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}>;
interface UserProfilePrivateInfo extends z.TypeOf<typeof UserProfilePrivateInfo> {
}

declare const UserProfilePublicInfoArray: z.ZodArray<z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}>, "many">;
interface UserProfilePublicInfoArray extends z.TypeOf<typeof UserProfilePublicInfoArray> {
}

declare const UserProfileStatusUpdate: z.ZodObject<{
    status: z.ZodEnum<["ACTIVE", "INACTIVE"]>;
}, "strip", z.ZodTypeAny, {
    status: "ACTIVE" | "INACTIVE";
}, {
    status: "ACTIVE" | "INACTIVE";
}>;
interface UserProfileStatusUpdate extends z.TypeOf<typeof UserProfileStatusUpdate> {
}

/**
 * AUTO GENERATED
 */

declare function UserProfileAdminApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    createProfilePublic: (data: UserProfileBulkRequest) => Promise<UserProfilePublicInfoArray>;
    getProfilesByPublicId: (queryParams: {
        publicId: string | null;
    }) => Promise<UserProfileInfo>;
    deleteProfile_ByUserId: (userId: string) => Promise<UserProfilePrivateInfo>;
    getProfiles_ByUserId: (userId: string) => Promise<UserProfilePrivateInfo>;
    updateProfile_ByUserId: (userId: string, data: UserProfileAdmin) => Promise<UserProfilePrivateInfo>;
    patchProfileStatus_ByUserId: (userId: string, data: UserProfileStatusUpdate) => Promise<UserProfilePrivateInfo>;
    getProfilesCustomAttributes_ByUserId: (userId: string) => Promise<unknown>;
    updateProfileCustomAttribute_ByUserId: (userId: string, data: any) => Promise<unknown>;
    getProfilesPrivateCustomAttributes_ByUserId: (userId: string) => Promise<unknown>;
    updateProfilePrivateCustomAttribute_ByUserId: (userId: string, data: any) => Promise<unknown>;
};

declare const FileUploadUrlInfo: z.ZodObject<{
    accessUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    contentType: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    method: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    url: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    accessUrl?: string | null | undefined;
    contentType?: string | null | undefined;
    method?: string | null | undefined;
    url?: string | null | undefined;
}, {
    accessUrl?: string | null | undefined;
    contentType?: string | null | undefined;
    method?: string | null | undefined;
    url?: string | null | undefined;
}>;
interface FileUploadUrlInfo extends z.TypeOf<typeof FileUploadUrlInfo> {
}

/**
 * AUTO GENERATED
 */

declare function FileUploadAdminApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    createFile_ByUserId: (userId: string, queryParams: {
        fileType: string | null;
        category?: string | null;
    }) => Promise<FileUploadUrlInfo>;
    createFile_ByFolder: (folder: string, queryParams: {
        fileType: string | null;
    }) => Promise<FileUploadUrlInfo>;
};

/**
 * AUTO GENERATED
 */

declare function AnonymizationAdminApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    deleteAnonymizationProfile_ByUserId: (userId: string) => Promise<unknown>;
};

declare const RetrieveTimeResponse: z.ZodObject<{
    currentTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    currentTime?: string | null | undefined;
}, {
    currentTime?: string | null | undefined;
}>;
interface RetrieveTimeResponse extends z.TypeOf<typeof RetrieveTimeResponse> {
}

/**
 * AUTO GENERATED
 */

declare function MiscApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getMiscTime: () => Promise<RetrieveTimeResponse>;
    getMiscCountries_DEPRECATED: (queryParams?: {
        lang?: string | null | undefined;
    } | undefined) => Promise<CountryObjectArray>;
    getMiscLanguages: () => Promise<unknown>;
    getMiscTimezones: () => Promise<unknown>;
};

declare const NamespaceSimpleInfo: z.ZodObject<{
    displayName: z.ZodString;
}, "strip", z.ZodTypeAny, {
    displayName: string;
}, {
    displayName: string;
}>;
interface NamespaceSimpleInfo extends z.TypeOf<typeof NamespaceSimpleInfo> {
}

/**
 * AUTO GENERATED
 */

declare function NamespaceApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getNamespaces: (queryParams?: {
        activeOnly?: boolean | null | undefined;
    } | undefined) => Promise<NamespaceInfoArray>;
    getNamespace_ByNamespace: () => Promise<NamespaceSimpleInfo>;
    getPublisher: () => Promise<NamespacePublisherInfo>;
};

declare const UserProfileCreate: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
}, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
}>;
interface UserProfileCreate extends z.TypeOf<typeof UserProfileCreate> {
}

declare const UserProfilePrivateCreate: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
}, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
}>;
interface UserProfilePrivateCreate extends z.TypeOf<typeof UserProfilePrivateCreate> {
}

declare const UserProfilePublicInfo: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}>;
interface UserProfilePublicInfo extends z.TypeOf<typeof UserProfilePublicInfo> {
}

declare const UserProfileUpdate: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
}, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
}>;
interface UserProfileUpdate extends z.TypeOf<typeof UserProfileUpdate> {
}

declare const UserZipCode: z.ZodObject<{
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    zipCode?: string | null | undefined;
}, {
    zipCode?: string | null | undefined;
}>;
interface UserZipCode extends z.TypeOf<typeof UserZipCode> {
}

declare const UserZipCodeUpdate: z.ZodObject<{
    zipCode: z.ZodString;
}, "strip", z.ZodTypeAny, {
    zipCode: string;
}, {
    zipCode: string;
}>;
interface UserZipCodeUpdate extends z.TypeOf<typeof UserZipCodeUpdate> {
}

/**
 * AUTO GENERATED
 */

declare function UserProfileApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getProfilesPublic: (queryParams: {
        userIds: string | null;
    }) => Promise<UserProfilePublicInfoArray>;
    createProfilePublic: (data: UserProfileBulkRequest) => Promise<UserProfilePublicInfoArray>;
    getUsersMeProfiles: () => Promise<UserProfilePrivateInfo>;
    createUserMeProfile: (data: UserProfilePrivateCreate) => Promise<UserProfilePrivateInfo>;
    updateUserMeProfile: (data: UserProfileUpdate) => Promise<UserProfilePrivateInfo>;
    getProfiles_ByUserId: (userId: string) => Promise<UserProfileInfo>;
    createProfile_ByUserId: (userId: string, data: UserProfileCreate) => Promise<UserProfileInfo>;
    updateProfile_ByUserId: (userId: string, data: UserProfileUpdate) => Promise<UserProfileInfo>;
    getUsersMeProfilesZipCode: () => Promise<UserZipCode>;
    patchUserMeProfileZipCode: (data: UserZipCodeUpdate) => Promise<UserZipCode>;
    getProfilesPublicByPublicId: (queryParams: {
        publicId: string | null;
    }) => Promise<UserProfilePublicInfo>;
    getProfilesPublic_ByUserId: (userId: string) => Promise<UserProfilePublicInfo>;
    patchProfileStatus_ByUserId: (userId: string, data: UserProfileStatusUpdate) => Promise<UserProfileInfo>;
    getProfilesCustomAttributes_ByUserId: (userId: string) => Promise<unknown>;
    updateProfileCustomAttribute_ByUserId: (userId: string, data: any) => Promise<unknown>;
    getUsersMeProfilesPrivateCustomAttributes: () => Promise<unknown>;
    updateUserMeProfilePrivateCustomAttribute: (data: any) => Promise<unknown>;
};

/**
 * AUTO GENERATED
 */

declare function FileUploadApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    createFile_ByUserId: (userId: string, queryParams: {
        fileType: string | null;
        category?: string | null;
    }) => Promise<FileUploadUrlInfo>;
    createFile_ByFolder: (folder: string, queryParams: {
        fileType: string | null;
    }) => Promise<FileUploadUrlInfo>;
};

/**
 * AUTO GENERATED
 */

declare const Basic: {
    NamespaceAdminApi: typeof NamespaceAdminApi;
    ConfigAdminApi: typeof ConfigAdminApi;
    MiscAdminApi: typeof MiscAdminApi;
    UserProfileAdminApi: typeof UserProfileAdminApi;
    FileUploadAdminApi: typeof FileUploadAdminApi;
    AnonymizationAdminApi: typeof AnonymizationAdminApi;
    MiscApi: typeof MiscApi;
    NamespaceApi: typeof NamespaceApi;
    UserProfileApi: typeof UserProfileApi;
    FileUploadApi: typeof FileUploadApi;
};

/**
 * AUTO GENERATED
 */

declare class AnonymizationAdmin$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Anonymize user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11501&lt;/li&gt;&lt;/ul&gt;
     */
    deleteAnonymizationProfile_ByUserId(userId: string): Promise<IResponse<unknown>>;
}

/**
 * AUTO GENERATED
 */

declare class ConfigAdmin$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Create a config.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: created config&lt;/li&gt;&lt;/ul&gt;
     */
    createConfig(data: ConfigCreate): Promise<IResponse<ConfigInfo>>;
    /**
     * Delete a config.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: created config&lt;/li&gt;&lt;/ul&gt;
     */
    deleteConfig_ByConfigKey(configKey: string): Promise<IResponse<unknown>>;
    /**
     * Get a config.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: config&lt;/li&gt;&lt;/ul&gt;
     */
    getConfig_ByConfigKey(configKey: string): Promise<IResponse<ConfigInfo>>;
    /**
     * Update a config.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: created config&lt;/li&gt;&lt;/ul&gt;
     */
    patchConfig_ByConfigKey(configKey: string, data: ConfigUpdate): Promise<IResponse<ConfigInfo>>;
    /**
     * Get a publisher config.&lt;br&gt;It will return a publisher namespace config of the given namespace and key.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: config&lt;/li&gt;&lt;/ul&gt;
     */
    getPublisherConfig_ByConfigKey(configKey: string): Promise<IResponse<ConfigInfo>>;
}

/**
 * AUTO GENERATED
 */

declare class FileUploadAdmin$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Generate an upload URL for user content. It&#39;s valid for 10 minutes.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11102&lt;/li&gt;&lt;li&gt;&lt;i&gt;Default maximum file count per user&lt;/i&gt;: 10 files&lt;/li&gt;&lt;li&gt;&lt;i&gt;Default maximum file size per user&lt;/i&gt;: 104857600 bytes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: URL data&lt;/li&gt;&lt;/ul&gt;
     */
    createFile_ByUserId(userId: string, queryParams: {
        fileType: string | null;
        category?: string | null;
    }): Promise<IResponse<FileUploadUrlInfo>>;
    /**
     * Generate an upload URL. It&#39;s valid for 10 minutes.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11101&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: URL data&lt;/li&gt;&lt;/ul&gt;
     */
    createFile_ByFolder(folder: string, queryParams: {
        fileType: string | null;
    }): Promise<IResponse<FileUploadUrlInfo>>;
}

/**
 * AUTO GENERATED
 */

declare class MiscAdmin$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * @deprecated
     * List countries.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11204&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: country code list&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscCountries_DEPRECATED(queryParams?: {
        lang?: string | null;
    }): Promise<IResponse<CountryObjectArray>>;
    /**
     * List languages.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11206&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: language list&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscLanguages(): Promise<IResponse<unknown>>;
    /**
     * List time zones.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11205&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: time zones&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscTimezones(): Promise<IResponse<unknown>>;
    /**
     * List country groups. Will return all available country groups if the query param is not specified&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11203&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: list of country groups&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscCountrygroups(queryParams?: {
        groupCode?: string | null;
    }): Promise<IResponse<RetrieveCountryGroupResponseArray>>;
    /**
     * Add a country groups&lt;br&gt;Country code must follow ISO3166-1 alpha-2.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11201&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: newly created country group&lt;/li&gt;&lt;/ul&gt;
     */
    createMiscCountrygroup(data: AddCountryGroupRequest): Promise<IResponse<AddCountryGroupResponse>>;
    /**
     * Delete a country groups by its country group code. This endpoint usually used for testing purpose to cleanup test data.&lt;br&gt;
     */
    deleteMiscCountrygroup_ByCountryGroupCode(countryGroupCode: string): Promise<IResponse<unknown>>;
    /**
     * Update a country groups. The countryGroupCode must be exist beforehand.&lt;br&gt;Valid update behaviour :&lt;br/&gt;- To update &lt;i&gt;countryGroupName&lt;/i&gt; only, do not include &lt;i&gt;countries&lt;/i&gt; key or just specify it with empty array.&lt;br/&gt;- To update &lt;i&gt;countries&lt;/i&gt; only, do not include &lt;i&gt;countryGroupName&lt;/i&gt; key or just specify it with blank value.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11202&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: updated country group&lt;/li&gt;&lt;/ul&gt;
     */
    updateMiscCountrygroup_ByCountryGroupCode(countryGroupCode: string, data: UpdateCountryGroupRequest): Promise<IResponse<CountryGroupObject>>;
}

/**
 * AUTO GENERATED
 */

declare class NamespaceAdmin$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Get all namespaces.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11303&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: list of namespaces&lt;/li&gt;&lt;/ul&gt;
     */
    getNamespaces(queryParams?: {
        activeOnly?: boolean | null;
    }): Promise<IResponse<NamespaceInfoArray>>;
    /**
     * Create a namespace.&lt;br&gt;By default the namespace is enabled.&lt;br&gt;In multi tenant mode, parentNamespace will be automatically filled with requester namespace if the requester is using studio or publisher token, and it will be filled with studio namespace if the requester uses game token. An oauth client will also be created and the id will be returned. &lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11301&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: created namespace&lt;/li&gt;&lt;/ul&gt;
     */
    createNamespace(data: NamespaceCreate): Promise<IResponse<NamespaceInfo>>;
    /**
     * Delete a namespace.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11307&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: deleted namespace&lt;/li&gt;&lt;/ul&gt;
     */
    deleteNamespace_ByNamespace(): Promise<IResponse<NamespaceInfo>>;
    /**
     * Get a namespace.&lt;br&gt;In multi tenant mode, parentNamespace will be returned.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11304&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: namespace&lt;/li&gt;&lt;/ul&gt;
     */
    getNamespace_ByNamespace(queryParams?: {
        activeOnly?: boolean | null;
    }): Promise<IResponse<NamespaceInfo>>;
    /**
     * Get game namespaces.&lt;br&gt;In multi tenant mode, a given super admin namespace will return all game namespaces of studio namespaces&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11308&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: list of namespaces&lt;/li&gt;&lt;/ul&gt;
     */
    getGame(queryParams?: {
        activeOnly?: boolean | null;
    }): Promise<IResponse<NamespaceInfoArray>>;
    /**
     * Update namespace basic info.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11302&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: updated namespace&lt;/li&gt;&lt;/ul&gt;
     */
    patchBasic(data: NamespaceUpdate): Promise<IResponse<NamespaceInfo>>;
    /**
     * Get child namespaces.&lt;br&gt;If input namespace is publisher namespace, then it will return its all studio namespace.&lt;br&gt;If input namespace is studio namespace, then it will return its all game namespace.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: list of child namespaces&lt;/li&gt;&lt;/ul&gt;
     */
    getChild(queryParams?: {
        activeOnly?: boolean | null;
    }): Promise<IResponse<NamespaceInfoArray>>;
    /**
     * Change a namespace status.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;Action code&lt;i&gt;&lt;/i&gt;: 11306&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: updated namespace&lt;/li&gt;&lt;/ul&gt;
     */
    patchStatus(data: NamespaceStatusUpdate): Promise<IResponse<NamespaceInfo>>;
    /**
     * Get context of namespace.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: context of namespace&lt;/li&gt;&lt;/ul&gt;
     */
    getContext(): Promise<IResponse<NamespaceContext>>;
    /**
     * Get namespace info related publisher namespace.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11305&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Namespace info related publisher namespace&lt;/li&gt;&lt;/ul&gt;
     */
    getPublisher(): Promise<IResponse<NamespacePublisherInfo>>;
}

/**
 * AUTO GENERATED
 */

declare class UserProfileAdmin$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Admin get user public profile by ids.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;ADMIN:NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=2 &lt;b&gt;(GET)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11405&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profiles&lt;/li&gt;&lt;/ul&gt;
     */
    createProfilePublic(data: UserProfileBulkRequest): Promise<IResponse<UserProfilePublicInfoArray>>;
    /**
     * Get user profile by public id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile info&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesByPublicId(queryParams: {
        publicId: string | null;
    }): Promise<IResponse<UserProfileInfo>>;
    /**
     * Delete user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11407&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Delete user profile&lt;/li&gt;&lt;/ul&gt;
     */
    deleteProfile_ByUserId(userId: string): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Get user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt;
     */
    getProfiles_ByUserId(userId: string): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Update user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated user profile&lt;/li&gt;&lt;/ul&gt;
     */
    updateProfile_ByUserId(userId: string, data: UserProfileAdmin): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Update user profile status.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11406&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;/ul&gt;
     */
    patchProfileStatus_ByUserId(userId: string, data: UserProfileStatusUpdate): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Get user custom attributes.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: custom attributes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesCustomAttributes_ByUserId(userId: string): Promise<IResponse<unknown>>;
    /**
     * Update partially custom attributes tied to the user id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt;: allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    updateProfileCustomAttribute_ByUserId(userId: string, data: any): Promise<IResponse<unknown>>;
    /**
     * Get user private custom attributes.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: custom attributes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesPrivateCustomAttributes_ByUserId(userId: string): Promise<IResponse<unknown>>;
    /**
     * Update partially private custom attributes tied to the user id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt;: allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    updateProfilePrivateCustomAttribute_ByUserId(userId: string, data: any): Promise<IResponse<unknown>>;
}

declare const CountryObject: z.ZodObject<{
    code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    code?: string | null | undefined;
    name?: string | null | undefined;
}, {
    code?: string | null | undefined;
    name?: string | null | undefined;
}>;
interface CountryObject extends z.TypeOf<typeof CountryObject> {
}

declare const ErrorEntity: z.ZodObject<{
    devStackTrace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorCode: z.ZodNumber;
    errorMessage: z.ZodString;
    messageVariables: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>;
    requiredPermission: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        action: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        resource: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        action?: number | null | undefined;
        resource?: string | null | undefined;
    }, {
        action?: number | null | undefined;
        resource?: string | null | undefined;
    }>>>;
}, "strip", z.ZodTypeAny, {
    devStackTrace?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    requiredPermission?: {
        action?: number | null | undefined;
        resource?: string | null | undefined;
    } | null | undefined;
    errorCode: number;
    errorMessage: string;
}, {
    devStackTrace?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    requiredPermission?: {
        action?: number | null | undefined;
        resource?: string | null | undefined;
    } | null | undefined;
    errorCode: number;
    errorMessage: string;
}>;
interface ErrorEntity extends z.TypeOf<typeof ErrorEntity> {
}

declare const FieldValidationError: z.ZodObject<{
    errorCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorField: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorMessage: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorValue: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    messageVariables: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    errorCode?: string | null | undefined;
    errorMessage?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    errorField?: string | null | undefined;
    errorValue?: string | null | undefined;
}, {
    errorCode?: string | null | undefined;
    errorMessage?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    errorField?: string | null | undefined;
    errorValue?: string | null | undefined;
}>;
interface FieldValidationError extends z.TypeOf<typeof FieldValidationError> {
}

declare const Permission: z.ZodObject<{
    action: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    resource: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    action?: number | null | undefined;
    resource?: string | null | undefined;
}, {
    action?: number | null | undefined;
    resource?: string | null | undefined;
}>;
interface Permission extends z.TypeOf<typeof Permission> {
}

declare const RetrieveCountryGroupResponse: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface RetrieveCountryGroupResponse extends z.TypeOf<typeof RetrieveCountryGroupResponse> {
}

declare const ValidationErrorEntity: z.ZodObject<{
    errorCode: z.ZodNumber;
    errorMessage: z.ZodString;
    errors: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        errorCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        errorField: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        errorMessage: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        errorValue: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        messageVariables: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>;
    }, "strip", z.ZodTypeAny, {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }, {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }>, "many">>>;
}, "strip", z.ZodTypeAny, {
    errors?: {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }[] | null | undefined;
    errorCode: number;
    errorMessage: string;
}, {
    errors?: {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }[] | null | undefined;
    errorCode: number;
    errorMessage: string;
}>;
interface ValidationErrorEntity extends z.TypeOf<typeof ValidationErrorEntity> {
}

/**
 * AUTO GENERATED
 */

declare class FileUpload$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Generate an upload URL for user content. It&#39;s valid for 10 minutes.&lt;br/&gt;There are 2 kinds of storage limitation per user : maximum file count and maximum file size.&lt;br/&gt;The threshold of those limitations is different between upload category that is used.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11102&lt;/li&gt;&lt;li&gt;&lt;i&gt;Default maximum file count per user&lt;/i&gt;: 10 files&lt;/li&gt;&lt;li&gt;&lt;i&gt;Default maximum file size per user&lt;/i&gt;: 104857600 bytes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: URL data&lt;/li&gt;&lt;/ul&gt;
     */
    createFile_ByUserId(userId: string, queryParams: {
        fileType: string | null;
        category?: string | null;
    }): Promise<IResponse<FileUploadUrlInfo>>;
    /**
     * Generate an upload URL. It&#39;s valid for 10 minutes.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11101&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: URL data&lt;/li&gt;&lt;/ul&gt;
     */
    createFile_ByFolder(folder: string, queryParams: {
        fileType: string | null;
    }): Promise<IResponse<FileUploadUrlInfo>>;
}

/**
 * AUTO GENERATED
 */

declare class Misc$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Get server time
     */
    getMiscTime(): Promise<IResponse<RetrieveTimeResponse>>;
    /**
     * @deprecated
     * List countries.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: country code list&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscCountries_DEPRECATED(queryParams?: {
        lang?: string | null;
    }): Promise<IResponse<CountryObjectArray>>;
    /**
     * List languages.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: language list&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscLanguages(): Promise<IResponse<unknown>>;
    /**
     * List time zones.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: time zones&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscTimezones(): Promise<IResponse<unknown>>;
}

/**
 * AUTO GENERATED
 */

declare class Namespace$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Get all namespaces.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11303&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: list of namespaces&lt;/li&gt;&lt;/ul&gt;
     */
    getNamespaces(queryParams?: {
        activeOnly?: boolean | null;
    }): Promise<IResponse<NamespaceInfoArray>>;
    /**
     * Get a namespace info.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: namespace info&lt;/li&gt;&lt;/ul&gt;
     */
    getNamespace_ByNamespace(): Promise<IResponse<NamespaceSimpleInfo>>;
    /**
     * Get namespace info related publisher namespace.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11305&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Namespace info related publisher namespace&lt;/li&gt;&lt;/ul&gt;
     */
    getPublisher(): Promise<IResponse<NamespacePublisherInfo>>;
}

/**
 * AUTO GENERATED
 */

declare class UserProfile$ {
    private axiosInstance;
    private namespace;
    private useSchemaValidation;
    constructor(axiosInstance: AxiosInstance, namespace: string, useSchemaValidation?: boolean);
    /**
     * Get user public profile by ids.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11405&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profiles&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesPublic(queryParams: {
        userIds: string | null;
    }): Promise<IResponse<UserProfilePublicInfoArray>>;
    /**
     * Bulk get user public profile by ids.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profiles&lt;/li&gt;&lt;/ul&gt;
     */
    createProfilePublic(data: UserProfileBulkRequest): Promise<IResponse<UserProfilePublicInfoArray>>;
    /**
     * Get my profile&lt;br&gt;&lt;b&gt;Client with user token can get user profile in target namespace&lt;/b&gt;&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Path&#39;s namespace&lt;/i&gt; : &lt;ul&gt;&lt;li&gt;can be filled with &lt;b&gt;publisher namespace&lt;/b&gt; in order to get &lt;b&gt;publisher user profile&lt;/b&gt;&lt;/li&gt;&lt;li&gt;can be filled with &lt;b&gt;game namespace&lt;/b&gt; in order to get &lt;b&gt;game user profile&lt;/b&gt;&lt;/li&gt;&lt;/ul&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;/ul&gt;
     */
    getUsersMeProfiles(): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Create my profile.&lt;br&gt;&lt;b&gt;Client with user token can create user profile in target namespace&lt;/b&gt;&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11401&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Created user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Path&#39;s namespace&lt;/i&gt; : &lt;ul&gt;&lt;li&gt;can be filled with &lt;b&gt;publisher namespace&lt;/b&gt; in order to create &lt;b&gt;publisher user profile&lt;/b&gt;&lt;/li&gt;&lt;li&gt;can be filled with &lt;b&gt;game namespace&lt;/b&gt; in order to create &lt;b&gt;game user profile&lt;/b&gt;&lt;/li&gt;&lt;/ul&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Country&lt;/i&gt; : ISO3166-1 alpha-2 two letter, e.g. US &lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;/ul&gt;
     */
    createUserMeProfile(data: UserProfilePrivateCreate): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Update my profile.&lt;br&gt;Updates user profile in the target namespace (namespace in the path). If token&#39;s namespace doesn&#39;t match the target namespace, the service automatically maps the token&#39;s user ID into the user ID in the target namespace. The endpoint returns the updated user profile on a successful call.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Path&#39;s namespace&lt;/i&gt; : &lt;ul&gt;&lt;li&gt;can be filled with &lt;b&gt;publisher namespace&lt;/b&gt; in order to update &lt;b&gt;publisher user profile&lt;/b&gt;&lt;/li&gt;&lt;li&gt;can be filled with &lt;b&gt;game namespace&lt;/b&gt; in order to update &lt;b&gt;game user profile&lt;/b&gt;&lt;/li&gt;&lt;/ul&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;/ul&gt;
     */
    updateUserMeProfile(data: UserProfileUpdate): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Get user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;/ul&gt;
     */
    getProfiles_ByUserId(userId: string): Promise<IResponse<UserProfileInfo>>;
    /**
     * Create user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11401&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Created user profile&lt;/li&gt;&lt;/ul&gt;
     */
    createProfile_ByUserId(userId: string, data: UserProfileCreate): Promise<IResponse<UserProfileInfo>>;
    /**
     * Update user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated user profile&lt;/li&gt;&lt;/ul&gt;
     */
    updateProfile_ByUserId(userId: string, data: UserProfileUpdate): Promise<IResponse<UserProfileInfo>>;
    /**
     * Get my zip code.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11407&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user zip code&lt;/li&gt;&lt;/ul&gt;
     */
    getUsersMeProfilesZipCode(): Promise<IResponse<UserZipCode>>;
    /**
     * Update my zip code.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11408&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user zip code&lt;/li&gt;&lt;/ul&gt;
     */
    patchUserMeProfileZipCode(data: UserZipCodeUpdate): Promise<IResponse<UserZipCode>>;
    /**
     * Get user public profile by public id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profile&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesPublicByPublicId(queryParams: {
        publicId: string | null;
    }): Promise<IResponse<UserProfilePublicInfo>>;
    /**
     * Get user profile public info.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11404&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profile&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesPublic_ByUserId(userId: string): Promise<IResponse<UserProfilePublicInfo>>;
    /**
     * Update user profile status.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11406&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;/ul&gt;
     */
    patchProfileStatus_ByUserId(userId: string, data: UserProfileStatusUpdate): Promise<IResponse<UserProfileInfo>>;
    /**
     * Get custom attributes info.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11404&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesCustomAttributes_ByUserId(userId: string): Promise<IResponse<unknown>>;
    /**
     * Update partially custom attributes tied to user id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt; : allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    updateProfileCustomAttribute_ByUserId(userId: string, data: any): Promise<IResponse<unknown>>;
    /**
     * Get my private custom attributes.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: custom attributes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt;
     */
    getUsersMeProfilesPrivateCustomAttributes(): Promise<IResponse<unknown>>;
    /**
     * Update partially private custom attributes tied to me.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt;: allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    updateUserMeProfilePrivateCustomAttribute(data: any): Promise<IResponse<unknown>>;
}

export { AddCountryGroupRequest, AddCountryGroupResponse, AnonymizationAdmin$, AnonymizationAdminApi, Basic, ConfigAdmin$, ConfigAdminApi, ConfigCreate, ConfigInfo, ConfigUpdate, CountryGroupObject, CountryObject, CountryObjectArray, ErrorEntity, FieldValidationError, FileUpload$, FileUploadAdmin$, FileUploadAdminApi, FileUploadApi, FileUploadUrlInfo, Misc$, MiscAdmin$, MiscAdminApi, MiscApi, Namespace$, NamespaceAdmin$, NamespaceAdminApi, NamespaceApi, NamespaceContext, NamespaceCreate, NamespaceInfo, NamespaceInfoArray, NamespacePublisherInfo, NamespaceSimpleInfo, NamespaceStatusUpdate, NamespaceUpdate, Permission, RetrieveCountryGroupResponse, RetrieveCountryGroupResponseArray, RetrieveTimeResponse, UpdateCountryGroupRequest, UserProfile$, UserProfileAdmin, UserProfileAdmin$, UserProfileAdminApi, UserProfileApi, UserProfileBulkRequest, UserProfileCreate, UserProfileInfo, UserProfilePrivateCreate, UserProfilePrivateInfo, UserProfilePublicInfo, UserProfilePublicInfoArray, UserProfileStatusUpdate, UserProfileUpdate, UserZipCode, UserZipCodeUpdate, ValidationErrorEntity };
